import { M as MastraStorage, T as TABLE_NAMES, S as StorageColumn, b as StorageThreadType, c as MessageType, d as StorageGetMessagesArg, E as EvalRow } from '../../base-CHNzbTDj.js';
import 'ai';
import '../../base-eWkcLLSb.js';
import '@opentelemetry/api';
import '../../index-C5uPdbs4.js';
import 'pino';
import 'stream';
import '@opentelemetry/sdk-trace-base';
import '../../types-m9RryK9a.js';
import 'sift';
import 'zod';
import 'json-schema';
import '../../vector/index.js';
import '../../voice/index.js';
import '../../tts/index.js';

interface LibSQLConfig {
    url: string;
    authToken?: string;
}
declare class LibSQLStore extends MastraStorage {
    private client;
    constructor({ config }: {
        config: LibSQLConfig;
    });
    protected rewriteDbUrl(url: string): string;
    private getCreateTableSQL;
    createTable({ tableName, schema, }: {
        tableName: TABLE_NAMES;
        schema: Record<string, StorageColumn>;
    }): Promise<void>;
    clearTable({ tableName }: {
        tableName: TABLE_NAMES;
    }): Promise<void>;
    private prepareStatement;
    insert({ tableName, record }: {
        tableName: TABLE_NAMES;
        record: Record<string, any>;
    }): Promise<void>;
    batchInsert({ tableName, records }: {
        tableName: TABLE_NAMES;
        records: Record<string, any>[];
    }): Promise<void>;
    load<R>({ tableName, keys }: {
        tableName: TABLE_NAMES;
        keys: Record<string, string>;
    }): Promise<R | null>;
    getThreadById({ threadId }: {
        threadId: string;
    }): Promise<StorageThreadType | null>;
    getThreadsByResourceId({ resourceId }: {
        resourceId: string;
    }): Promise<StorageThreadType[]>;
    saveThread({ thread }: {
        thread: StorageThreadType;
    }): Promise<StorageThreadType>;
    updateThread({ id, title, metadata, }: {
        id: string;
        title: string;
        metadata: Record<string, unknown>;
    }): Promise<StorageThreadType>;
    deleteThread({ threadId }: {
        threadId: string;
    }): Promise<void>;
    private parseRow;
    getMessages<T extends MessageType[]>({ threadId, selectBy }: StorageGetMessagesArg): Promise<T>;
    saveMessages({ messages }: {
        messages: MessageType[];
    }): Promise<MessageType[]>;
    private transformEvalRow;
    getEvalsByAgentName(agentName: string, type?: 'test' | 'live'): Promise<EvalRow[]>;
    getTraces({ name, scope, page, perPage, attributes, }?: {
        name?: string;
        scope?: string;
        page: number;
        perPage: number;
        attributes?: Record<string, string>;
    }): Promise<any[]>;
}

export { LibSQLStore as DefaultStorage, type LibSQLConfig, LibSQLStore };
